|logo| Girder |build-status| |docs-status| |license-badge| |codecov-badge|
==========================================================================

**Data Management Platform**

Girder is a free and open source web-based data management platform developed by
`Kitware <https://kitware.com>`_ as part of the `Resonant <http://resonant.kitware.com>`_
data and analytics ecosystem.

|kitware-logo|

Documentation of the Girder platform can be found at
https://girder.readthedocs.io.

For questions, comments, or to get in touch with the maintainers, head to our `Discourse forum <https://discourse.girder.org>`_.

We'd love for you to `contribute to Girder <CONTRIBUTING.rst>`_.

.. |logo| image:: girder/web_client/static/img/Girder_Favicon.png

.. |kitware-logo| image:: https://www.kitware.com/main/wp-content/uploads/2021/10/Kitware-Wordmark.svg
    :target: https://kitware.com
    :alt: Kitware Logo
    :width: 180

.. |build-status| image:: https://circleci.com/gh/girder/girder.png?style=shield
    :target: https://circleci.com/gh/girder/girder
    :alt: Build Status

.. |docs-status| image:: https://readthedocs.org/projects/girder/badge?version=latest
    :target: https://girder.readthedocs.org
    :alt: Documentation Status

.. |license-badge| image:: docs/license.png
    :target: https://pypi.python.org/pypi/girder
    :alt: License

.. |codecov-badge| image:: https://img.shields.io/codecov/c/github/girder/girder.svg
    :target: https://codecov.io/gh/girder/girder
    :alt: Coverage Status
